@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,14 +19,18 @@ from typing import Dict, Type
 from .base import ClusterManagerTransport
 from .grpc import ClusterManagerGrpcTransport
 from .grpc_asyncio import ClusterManagerGrpcAsyncIOTransport
+from .rest import ClusterManagerRestInterceptor, ClusterManagerRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ClusterManagerTransport]]
 _transport_registry["grpc"] = ClusterManagerGrpcTransport
 _transport_registry["grpc_asyncio"] = ClusterManagerGrpcAsyncIOTransport
+_transport_registry["rest"] = ClusterManagerRestTransport
 
 __all__ = (
     "ClusterManagerTransport",
     "ClusterManagerGrpcTransport",
     "ClusterManagerGrpcAsyncIOTransport",
+    "ClusterManagerRestTransport",
+    "ClusterManagerRestInterceptor",
 )
